@@ -4,4 +4,4 @@ TODO: write docs
 __title__ = "Guide Offset"
 
 from .base import GuideOffset
-from .simple import GuideOffsetSimple
+from .pwi import GuideOffsetPWI
